"use client"

import { motion } from "framer-motion"
import { Loader2, RefreshCw, Loader } from "lucide-react"

interface LoadingSpinnerProps {
    variant?: "default" | "dots" | "circular" | "pulse"
    size?: "sm" | "md" | "lg"
    message?: string
    fullHeight?: boolean
    className?: string
}

export default function LoadingSpinnerVariants({
    variant = "default",
    size = "md",
    message,
    fullHeight = true,
    className,
}: LoadingSpinnerProps) {
    // Size mappings
    const sizeClasses = {
        sm: "h-6 w-6",
        md: "h-10 w-10",
        lg: "h-16 w-16",
    }

    const dotSizes = {
        sm: "h-1.5 w-1.5",
        md: "h-2.5 w-2.5",
        lg: "h-4 w-4",
    }

    // Container height
    const heightClass = fullHeight ? "min-h-[calc(100vh-4rem)]" : "min-h-[200px]"

    // Render the appropriate spinner based on variant
    const renderSpinner = () => {
        switch (variant) {
            case "dots":
                return (
                    <div className="flex space-x-2">
                        {[0, 1, 2].map((i) => (
                            <motion.div
                                key={i}
                                initial={{ opacity: 0.3, y: 0 }}
                                animate={{ opacity: [0.3, 1, 0.3], y: [0, -10, 0] }}
                                transition={{ duration: 1, repeat: Number.POSITIVE_INFINITY, delay: i * 0.2, ease: "easeInOut" }}
                                className={`${dotSizes[size]} bg-emerald-600 dark:bg-emerald-500 rounded-full`}
                            />
                        ))}
                    </div>
                )
            case "circular":
                return (
                    <div className="relative">
                        <motion.div
                            animate={{ rotate: 360 }}
                            transition={{ duration: 1.5, repeat: Number.POSITIVE_INFINITY, ease: "linear" }}
                        >
                            <RefreshCw className={`${sizeClasses[size]} text-emerald-600 dark:text-emerald-500`} />
                        </motion.div>
                    </div>
                )
            case "pulse":
                return (
                    <div className="relative">
                        <motion.div
                            animate={{ scale: [1, 1.2, 1], opacity: [0.7, 1, 0.7] }}
                            transition={{ duration: 1.5, repeat: Number.POSITIVE_INFINITY, ease: "easeInOut" }}
                        >
                            <Loader className={`${sizeClasses[size]} text-emerald-600 dark:text-emerald-500`} />
                        </motion.div>
                    </div>
                )
            default:
                return (
                    <div className="relative">
                        <motion.div
                            initial={{ opacity: 0.5, scale: 0.8 }}
                            animate={{ opacity: [0.5, 0.2, 0.5], scale: [0.8, 1.1, 0.8] }}
                            transition={{ duration: 2, repeat: Number.POSITIVE_INFINITY, ease: "easeInOut" }}
                            className="absolute inset-0 bg-emerald-500/10 dark:bg-emerald-500/5 rounded-full"
                            style={{
                                width: size === "sm" ? "24px" : size === "md" ? "40px" : "64px",
                                height: size === "sm" ? "24px" : size === "md" ? "40px" : "64px",
                            }}
                        />
                        <motion.div
                            animate={{ rotate: 360 }}
                            transition={{ duration: 1.5, repeat: Number.POSITIVE_INFINITY, ease: "linear" }}
                        >
                            <Loader2 className={`${sizeClasses[size]} text-emerald-600 dark:text-emerald-500`} />
                        </motion.div>
                    </div>
                )
        }
    }

    return (
        <div
            className={`flex flex-col justify-center items-center ${heightClass} ${className}`}
            role="status"
            aria-live="polite"
        >
            {renderSpinner()}

            {/* Optional loading message */}
            {message && (
                <motion.p
                    initial={{ opacity: 0 }}
                    animate={{ opacity: 1 }}
                    transition={{ delay: 0.5, duration: 0.5 }}
                    className="mt-4 text-slate-600 dark:text-slate-400 text-sm font-medium"
                >
                    {message}
                </motion.p>
            )}

            <span className="sr-only">Loading</span>
        </div>
    )
}
